@@ -2,7 +2,52 @@
 
 import numpy as np
 import pandas as pd
-from sktime.datatypes._panel._convert import from_nested_to_3d_numpy, is_nested_dataframe
+from os import cpu_count
+from sktime.datatypes._panel._convert import from_nested_to_3d_numpy
+from sktime.datatypes._panel._check import is_nested_dataframe
+
+def is_int(x):
+    """Check if x is of integer type, but not boolean."""
+    # boolean are subclasses of integers in Python, so explicitly exclude them
+    return isinstance(x, (int, np.integer)) and not isinstance(x, bool)
+
+def check_is_numeric(x):
+    if (isinstance(x, (int, np.integer)) or isinstance(x, (float, np.floating))) and not isinstance(x, bool):
+        return x
+    else:
+        raise ValueError('Expected a numerical value, but got {}'.format(type(x)))
+
+def check_is_boolean(x):
+    if isinstance(x, bool):
+        if x == 0 or x == 1:
+            x = bool(x)
+        return x
+    else:
+        raise ValueError('Expected a boolean, but got {}'.format(type(x)))
+
+
+
+def check_n_jobs(n_jobs):
+    """Check `n_jobs` parameter according to the scikit-learn convention.
+
+    Parameters
+    ----------
+    n_jobs : int, positive or -1
+        The number of jobs for parallelization.
+
+    Returns
+    -------
+    n_jobs : int
+        Checked number of jobs.
+    """
+    if n_jobs is None:
+        return 1
+    elif not is_int(n_jobs):
+        raise ValueError(f"`n_jobs` must be None or an integer, but found: {n_jobs}")
+    elif n_jobs < 0:
+        return cpu_count() + n_jobs + 1
+    else:
+        return min(n_jobs,cpu_count())
 
 def check_array_3D(X, coerce_to_numpy=True, is_univariate=False, min_timestamps=2):
     """
@@ -189,4 +234,4 @@ def check_is_numpy(X):
     raise ValueError(
         "Expected an python list or numpy array as input "
         "but got {}".format(str(type(X)))
-    )   
\ No newline at end of file
+    )   
